@@ -2,7 +2,7 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-import pbr.version
+from importlib import metadata
 
 from bandit.core import config  # noqa
 from bandit.core import context  # noqa
@@ -16,4 +16,4 @@ from bandit.core.constants import *  # noqa
 from bandit.core.issue import *  # noqa
 from bandit.core.test_properties import *  # noqa
 
-__version__ = pbr.version.VersionInfo("bandit").version_string()
+__version__ = metadata.version("bandit")
