@@ -19,23 +19,30 @@ on ``yaml.load`` and yaml.safe_load
 
 :Example:
 
+.. code-block:: none
+
     >> Issue: [yaml_load] Use of unsafe yaml load. Allows instantiation of
        arbitrary objects. Consider yaml.safe_load().
        Severity: Medium   Confidence: High
+       CWE: CWE-20 (https://cwe.mitre.org/data/definitions/20.html)
        Location: examples/yaml_load.py:5
     4 ystr = yaml.dump({'a' : 1, 'b' : 2, 'c' : 3})
     5 y = yaml.load(ystr)
     6 yaml.dump(y)
 
-
 .. seealso::
 
  - https://pyyaml.org/wiki/PyYAMLDocumentation#LoadingYAML
+ - https://cwe.mitre.org/data/definitions/20.html
 
 .. versionadded:: 1.0.0
 
+.. versionchanged:: 1.7.3
+    CWE information added
+
 """
 import bandit
+from bandit.core import issue
 from bandit.core import test_properties as test
 
 
@@ -55,11 +62,14 @@ def yaml_load(context):
             func == "load",
             not context.check_call_arg_value("Loader", "SafeLoader"),
             not context.check_call_arg_value("Loader", "CSafeLoader"),
+            not context.get_call_arg_at_position(1) == "SafeLoader",
+            not context.get_call_arg_at_position(1) == "CSafeLoader",
         ]
     ):
         return bandit.Issue(
             severity=bandit.MEDIUM,
             confidence=bandit.HIGH,
+            cwe=issue.Cwe.IMPROPER_INPUT_VALIDATION,
             text="Use of unsafe yaml load. Allows instantiation of"
             " arbitrary objects. Consider yaml.safe_load().",
             lineno=context.node.lineno,
